@@ -3,6 +3,10 @@ import numpy as np
 from spotPython.utils.init import fun_control_init
 from spotPython.hyperparameters.values import get_bound_values
 from spotPython.hyperparameters.values import get_control_key_value, set_control_key_value
+from spotPython.hyperparameters.values import get_var_type_from_var_name
+from spotPython.hyperparameters.values import add_core_model_to_fun_control
+from spotPython.light.regression.netlightregression import NetLightRegression
+from spotPython.hyperdict.light_hyper_dict import LightHyperDict
 
 
 def test_get_bound_values():
@@ -60,4 +64,18 @@ def test_get_control_key_value():
     # Test when key is in fun_control
     set_control_key_value(control_dict=fun_control, key="key1", value="value1")
     assert get_control_key_value(control_dict=fun_control, key="key1") == "value1"
-    
\ No newline at end of file
+
+
+def test_get_var_type_from_var_name():
+    fun_control = fun_control_init()
+    add_core_model_to_fun_control(core_model=NetLightRegression,
+                        fun_control=fun_control,
+                        hyper_dict=LightHyperDict)
+    var_type = get_control_key_value(control_dict=fun_control, key="var_type")
+    var_name = get_control_key_value(control_dict=fun_control, key="var_name")
+    vn = "l1"
+    assert var_type[var_name.index(vn)] == "int"
+    assert get_var_type_from_var_name(fun_control, vn) == "int"
+    vn = "initialization"
+    assert var_type[var_name.index(vn)] == "factor"
+    assert get_var_type_from_var_name(fun_control, vn) == "factor"
\ No newline at end of file
